/* SPDX-License-Identifier: ((GPL-2.0 WITH Linux-syscall-note) OR BSD-3-Clause) */
/* Do not edit directly, auto-generated from: */
/*	Documentation/netlink/specs/sunrpc_cache.yaml */
/* YNL-GEN uapi header */
/* To regenerate run: tools/net/ynl/ynl-regen.sh */

#ifndef _LINUX_SUNRPC_NETLINK_H
#define _LINUX_SUNRPC_NETLINK_H

#define SUNRPC_FAMILY_NAME	"sunrpc"
#define SUNRPC_FAMILY_VERSION	1

enum sunrpc_cache_type {
	SUNRPC_CACHE_TYPE_IP_MAP = 1,
	SUNRPC_CACHE_TYPE_UNIX_GID = 2,
};

enum {
	SUNRPC_A_CACHE_NOTIFY_CACHE_TYPE = 1,

	__SUNRPC_A_CACHE_NOTIFY_MAX,
	SUNRPC_A_CACHE_NOTIFY_MAX = (__SUNRPC_A_CACHE_NOTIFY_MAX - 1)
};

enum {
	SUNRPC_A_IP_MAP_SEQNO = 1,
	SUNRPC_A_IP_MAP_CLASS,
	SUNRPC_A_IP_MAP_ADDR,
	SUNRPC_A_IP_MAP_DOMAIN,
	SUNRPC_A_IP_MAP_NEGATIVE,
	SUNRPC_A_IP_MAP_EXPIRY,

	__SUNRPC_A_IP_MAP_MAX,
	SUNRPC_A_IP_MAP_MAX = (__SUNRPC_A_IP_MAP_MAX - 1)
};

enum {
	SUNRPC_A_IP_MAP_REQS_REQUESTS = 1,

	__SUNRPC_A_IP_MAP_REQS_MAX,
	SUNRPC_A_IP_MAP_REQS_MAX = (__SUNRPC_A_IP_MAP_REQS_MAX - 1)
};

enum {
	SUNRPC_A_UNIX_GID_SEQNO = 1,
	SUNRPC_A_UNIX_GID_UID,
	SUNRPC_A_UNIX_GID_GIDS,
	SUNRPC_A_UNIX_GID_NEGATIVE,
	SUNRPC_A_UNIX_GID_EXPIRY,

	__SUNRPC_A_UNIX_GID_MAX,
	SUNRPC_A_UNIX_GID_MAX = (__SUNRPC_A_UNIX_GID_MAX - 1)
};

enum {
	SUNRPC_A_UNIX_GID_REQS_REQUESTS = 1,

	__SUNRPC_A_UNIX_GID_REQS_MAX,
	SUNRPC_A_UNIX_GID_REQS_MAX = (__SUNRPC_A_UNIX_GID_REQS_MAX - 1)
};

enum {
	SUNRPC_A_CACHE_FLUSH_MASK = 1,

	__SUNRPC_A_CACHE_FLUSH_MAX,
	SUNRPC_A_CACHE_FLUSH_MAX = (__SUNRPC_A_CACHE_FLUSH_MAX - 1)
};

enum {
	SUNRPC_CMD_CACHE_NOTIFY = 1,
	SUNRPC_CMD_IP_MAP_GET_REQS,
	SUNRPC_CMD_IP_MAP_SET_REQS,
	SUNRPC_CMD_UNIX_GID_GET_REQS,
	SUNRPC_CMD_UNIX_GID_SET_REQS,
	SUNRPC_CMD_CACHE_FLUSH,

	__SUNRPC_CMD_MAX,
	SUNRPC_CMD_MAX = (__SUNRPC_CMD_MAX - 1)
};

#define SUNRPC_MCGRP_NONE	"none"
#define SUNRPC_MCGRP_EXPORTD	"exportd"

#endif /* _LINUX_SUNRPC_NETLINK_H */
